allow_DS_float
|
Set to True to allow DSdecimal instances to be created using floats; otherwise, they must be explicitly converted to str, with the user explicity setting the precision of digits and rounding. |
data_element_callback
|
Set to a callable function to be called from dcmread() every time a RawDataElement has been returned, before it is added to the Dataset. |
data_element_callback_kwargs
|
Set the keyword arguments passed to data_element_callback(). |
datetime_conversion
|
Set to True to convert the value(s) of elements with a VR of DA, DT and TM to datetime.date, datetime.datetime and datetime.time respectively. |
debug([debug_on, default_handler])
|
Turn on/off debugging of DICOM file reading and writing. |
enforce_valid_values
|
Raise exceptions if any value is not allowed by DICOM Standard. |
overlay_data_handlers
|
Handlers for converting (60xx,3000) Overlay Data |
pixel_data_handlers
|
Handlers for converting (7FE0,0010) Pixel Data. |
reset_data_element_callback()
|
Reset the data_element_callback() function to the default. |
use_DS_decimal
|
Set to True to use decimal.Decimal to hold the value for elements with a VR of ‘DS’. |